emacs-elpa-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[nongnu] elpa/drupal-mode 00fa57745f 005/308: Cleanup.


From: ELPA Syncer
Subject: [nongnu] elpa/drupal-mode 00fa57745f 005/308: Cleanup.
Date: Tue, 25 Jan 2022 10:58:54 -0500 (EST)

branch: elpa/drupal-mode
commit 00fa57745fba16389aadbb344de4ec30b68c8987
Author: Arne Jørgensen <arne@arnested.dk>
Commit: Arne Jørgensen <arne@arnested.dk>

    Cleanup.
    
    Remove left overs from when this was a major mode.
    
    Be consistent in the way we describe the package.
---
 dir                | 2 +-
 drupal-mode-pkg.el | 2 +-
 drupal-mode.el     | 8 ++++----
 3 files changed, 6 insertions(+), 6 deletions(-)

diff --git a/dir b/dir
index adabb75773..f180402973 100644
--- a/dir
+++ b/dir
@@ -15,4 +15,4 @@ File: dir,    Node: Top       This is the top of the INFO tree
 * Menu:
 
 Programming
-* Drupal: (drupal-mode).                 Advanced minor mode for developing in 
Drupal.
+* Drupal: (drupal-mode).                 Advanced minor mode for Drupal 
development.
diff --git a/drupal-mode-pkg.el b/drupal-mode-pkg.el
index 95122bb919..e9f71a475c 100644
--- a/drupal-mode-pkg.el
+++ b/drupal-mode-pkg.el
@@ -1,3 +1,3 @@
 (define-package "drupal-mode" "0.1.0"
-  "Advanced minor mode for developing in Drupal"
+  "Advanced minor mode for Drupal development"
   '((php-mode "1.5.0")))
diff --git a/drupal-mode.el b/drupal-mode.el
index dd4e5081a2..595b47a887 100644
--- a/drupal-mode.el
+++ b/drupal-mode.el
@@ -1,4 +1,4 @@
 ;;; drupal-mode.el --- Advanced minor mode for developing in Drupal
 
 ;; Copyright (C) 2012 Arne Jørgensen
 
@@ -86,7 +86,7 @@ First parameter is the Drupal version. Second parameter is 
the search term."
 
 ;;;###autoload
 (define-minor-mode drupal-mode
-  "Major mode for developing Drupal modules and code.\n\n\\{drupal-mode-map}"
+  "Advanced minor mode for Drupal development.\n\n\\{drupal-mode-map}"
   :group 'drupal
   :init-value nil
   :lighter "/Drupal"
@@ -153,7 +153,7 @@ According to http://drupal.org/coding-standards#indenting.";
   "Convert to unix style line ending.
 According to http://drupal.org/coding-standards#indenting you
 should save your files with unix style end of line."
-  (when (and (eq major-mode 'drupal-mode)
+  (when (and drupal-mode
             drupal-convert-line-ending
             (/= (coding-system-eol-type buffer-file-coding-system) 0))
     (if (or (eq drupal-convert-line-ending t)
@@ -166,7 +166,7 @@ should save your files with unix style end of line."
 
 (defun drupal-delete-trailing-whitespace ()
   "Delete trailing whitespace if in drupal mode."
-  (when (and (eq major-mode 'drupal-mode)
+  (when (and drupal-mode
             drupal-delete-trailing-whitespace)
     (delete-trailing-whitespace)))
 
@@ -1,4 +1,4 @@
-;;; drupal-mode.el --- Advanced minor mode for developing in Drupal
+;;; drupal-mode.el --- Advanced minor mode for Drupal development
 
 ;; Copyright (C) 2012 Arne Jørgensen



reply via email to

[Prev in Thread] Current Thread [Next in Thread]